'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var preact = require('preact');
var reshapePreactComponents = require('reshape-preact-components');
var marked = _interopDefault(require('marked'));
var Image = _interopDefault(require('@hashicorp/hashi-image'));

var _require = require('preact'),
    h = _require.h;

function CaratIcon() {
  return h(
    "svg",
    {
      width: "15",
      height: "9",
      viewBox: "0 0 15 9",
      fill: "none",
      xmlns: "http://www.w3.org/2000/svg"
    },
    h("line", {
      x1: "0.5",
      y1: "4.5",
      x2: "13.5",
      y2: "4.5",
      stroke: "#1563FF",
      strokeLinecap: "round"
    }),
    h("path", {
      d: "M10.3536 0.646447C10.1583 0.451184 9.84171 0.451184 9.64645 0.646447C9.45118 0.841709 9.45118 1.15829 9.64645 1.35355L10.3536 0.646447ZM13.5 4.5L13.8536 4.85355L14.2071 4.5L13.8536 4.14645L13.5 4.5ZM9.64645 7.64645C9.45118 7.84171 9.45118 8.15829 9.64645 8.35355C9.84171 8.54882 10.1583 8.54882 10.3536 8.35355L9.64645 7.64645ZM9.64645 1.35355L13.1464 4.85355L13.8536 4.14645L10.3536 0.646447L9.64645 1.35355ZM13.1464 4.14645L9.64645 7.64645L10.3536 8.35355L13.8536 4.85355L13.1464 4.14645Z",
      fill: "#1563FF"
    })
  );
}

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var Callouts = function (_Component) {
  _inherits(Callouts, _Component);

  function Callouts() {
    _classCallCheck(this, Callouts);

    return _possibleConstructorReturn(this, (Callouts.__proto__ || Object.getPrototypeOf(Callouts)).apply(this, arguments));
  }

  _createClass(Callouts, [{
    key: 'render',
    value: function render() {
      var data = reshapePreactComponents.decode(this.props._data);

      var getCalloutContent = function getCalloutContent(item) {
        return preact.h(
          'div',
          { 'class': 'callout-content' },
          item.image && preact.h(
            'div',
            { 'class': 'callout-icon' },
            preact.h(Image, {
              src: item.image.url,
              svg: item.image.format === 'svg',
              alt: item.image.alt
            })
          ),
          preact.h(
            'div',
            { 'class': 'callout-text' },
            preact.h('h3', {
              dangerouslySetInnerHTML: {
                __html: marked.inlineLexer(item.title, [])
              }
            }),
            preact.h('div', {
              'class': 'callout-description',
              dangerouslySetInnerHTML: {
                __html: item.description ? marked(item.description) : ''
              }
            })
          )
        );
      };

      var getCalloutButton = function getCalloutButton(link, theme) {
        return preact.h(
          'div',
          { 'class': 'callout-button ' + (theme || '') },
          preact.h(
            'span',
            null,
            link.title
          ),
          preact.h(CaratIcon, null)
        );
      };

      return preact.h(
        'ul',
        { 'class': 'g-callouts' },
        data.items.map(function (item) {
          return preact.h(
            'li',
            { 'class': 'callout-container', key: item.title },
            item.link && preact.h(
              'a',
              _extends({
                href: item.link.url,
                'class': 'callout-box ' + (item.image ? 'has-image' : 'no-image')
              }, item.link.external && { rel: 'noopener', target: '_blank' }),
              getCalloutContent(item),
              getCalloutButton(item.link, data.theme)
            ),
            !item.link && preact.h(
              'div',
              {
                'class': 'callout-box ' + (item.image ? 'has-image' : 'no-image')
              },
              getCalloutContent(item)
            )
          );
        })
      );
    }
  }]);

  return Callouts;
}(preact.Component);

module.exports = Callouts;
